@@ -560,7 +560,7 @@ class Session:
             ok = True
             try:
                 self._send_request(socket, host, method, path, headers, data, json)
-            except _SendFailed:
+            except (_SendFailed, OSError):
                 ok = False
             if ok:
                 # Read the H of "HTTP/1.1" to make sure the socket is alive. send can appear to work
@@ -569,7 +569,10 @@ class Session:
                     result = socket.recv(1)
                 else:
                     result = bytearray(1)
-                    socket.recv_into(result)
+                    try:
+                        socket.recv_into(result)
+                    except OSError:
+                        pass
                 if result == b"H":
                     # Things seem to be ok so break with socket set.
                     break
@@ -577,7 +580,7 @@ class Session:
             socket = None
 
         if not socket:
-            raise OutOfRetries()
+            raise OutOfRetries("Repeated socket failures")
 
         resp = Response(socket, self)  # our response
         if "location" in resp.headers and 300 <= resp.status_code <= 399:
