@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+#
+# SPDX-License-Identifier: Unlicense
+
 from unittest import mock
 import mocket
 import pytest
@@ -30,7 +34,10 @@ def test_get_twice():
         ]
     )
     sock.send.assert_has_calls(
-        [mock.call(b"Host: "), mock.call(b"wifitest.adafruit.com"),]
+        [
+            mock.call(b"Host: "),
+            mock.call(b"wifitest.adafruit.com"),
+        ]
     )
     assert r.text == str(text, "utf-8")
 
@@ -45,7 +52,10 @@ def test_get_twice():
         ]
     )
     sock.send.assert_has_calls(
-        [mock.call(b"Host: "), mock.call(b"wifitest.adafruit.com"),]
+        [
+            mock.call(b"Host: "),
+            mock.call(b"wifitest.adafruit.com"),
+        ]
     )
 
     assert r.text == str(text, "utf-8")
@@ -72,7 +82,10 @@ def test_get_twice_after_second():
         ]
     )
     sock.send.assert_has_calls(
-        [mock.call(b"Host: "), mock.call(b"wifitest.adafruit.com"),]
+        [
+            mock.call(b"Host: "),
+            mock.call(b"wifitest.adafruit.com"),
+        ]
     )
 
     r2 = s.get("https://" + host + path + "2")
@@ -86,7 +99,10 @@ def test_get_twice_after_second():
         ]
     )
     sock.send.assert_has_calls(
-        [mock.call(b"Host: "), mock.call(b"wifitest.adafruit.com"),]
+        [
+            mock.call(b"Host: "),
+            mock.call(b"wifitest.adafruit.com"),
+        ]
     )
     sock.connect.assert_called_once_with((host, 443))
     pool.socket.assert_called_once()
@@ -117,7 +133,10 @@ def test_connect_out_of_memory():
         ]
     )
     sock.send.assert_has_calls(
-        [mock.call(b"Host: "), mock.call(b"wifitest.adafruit.com"),]
+        [
+            mock.call(b"Host: "),
+            mock.call(b"wifitest.adafruit.com"),
+        ]
     )
     assert r.text == str(text, "utf-8")
 
@@ -131,7 +150,10 @@ def test_connect_out_of_memory():
         ]
     )
     sock3.send.assert_has_calls(
-        [mock.call(b"Host: "), mock.call(b"wifitest2.adafruit.com"),]
+        [
+            mock.call(b"Host: "),
+            mock.call(b"wifitest2.adafruit.com"),
+        ]
     )
 
     assert r.text == str(text, "utf-8")
@@ -153,11 +175,17 @@ def test_second_send_fails():
     r = s.get("https://" + host + path)
 
     sock.send.assert_has_calls(
-        [mock.call(b"testwifi/index.html"),]
+        [
+            mock.call(b"testwifi/index.html"),
+        ]
     )
 
     sock.send.assert_has_calls(
-        [mock.call(b"Host: "), mock.call(b"wifitest.adafruit.com"), mock.call(b"\r\n"),]
+        [
+            mock.call(b"Host: "),
+            mock.call(b"wifitest.adafruit.com"),
+            mock.call(b"\r\n"),
+        ]
     )
     assert r.text == str(text, "utf-8")
 
@@ -185,11 +213,17 @@ def test_second_send_lies_recv_fails():
     r = s.get("https://" + host + path)
 
     sock.send.assert_has_calls(
-        [mock.call(b"testwifi/index.html"),]
+        [
+            mock.call(b"testwifi/index.html"),
+        ]
     )
 
     sock.send.assert_has_calls(
-        [mock.call(b"Host: "), mock.call(b"wifitest.adafruit.com"), mock.call(b"\r\n"),]
+        [
+            mock.call(b"Host: "),
+            mock.call(b"wifitest.adafruit.com"),
+            mock.call(b"\r\n"),
+        ]
     )
     assert r.text == str(text, "utf-8")
 
